package org.apache.bcel.generic;

import java.util.Collection;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;
import org.apache.bcel.classfile.Utility;

/* loaded from: org_apache_bcel_generic.jar:org/apache/bcel/generic/InstructionHandle.class */
public class InstructionHandle {
    public static final InstructionHandle[] EMPTY_ARRAY = new InstructionHandle[0];
    static final InstructionTargeter[] EMPTY_INSTRUCTION_TARGETER_ARRAY = new InstructionTargeter[0];
    private InstructionHandle next;
    private InstructionHandle prev;
    private Instruction instruction;

    @Deprecated
    protected int i_position = -1;
    private Set<InstructionTargeter> targeters;
    private Map<Object, Object> attributes;

    /* JADX INFO: Access modifiers changed from: package-private */
    public static InstructionHandle getInstructionHandle(Instruction i) {
        return new InstructionHandle(i);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public InstructionHandle(Instruction i) {
        setInstruction(i);
    }

    public void accept(Visitor v) {
        this.instruction.accept(v);
    }

    public void addAttribute(Object key, Object attr) {
        if (this.attributes == null) {
            this.attributes = new HashMap(3);
        }
        this.attributes.put(key, attr);
    }

    @Deprecated
    protected void addHandle() {
    }

    public void addTargeter(InstructionTargeter t) {
        if (this.targeters == null) {
            this.targeters = new HashSet();
        }
        this.targeters.add(t);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void dispose() {
        this.prev = null;
        this.next = null;
        this.instruction.dispose();
        this.instruction = null;
        this.i_position = -1;
        this.attributes = null;
        removeAllTargeters();
    }

    public Object getAttribute(Object key) {
        if (this.attributes != null) {
            return this.attributes.get(key);
        }
        return null;
    }

    public Collection<Object> getAttributes() {
        if (this.attributes == null) {
            this.attributes = new HashMap(3);
        }
        return this.attributes.values();
    }

    public final Instruction getInstruction() {
        return this.instruction;
    }

    public final InstructionHandle getNext() {
        return this.next;
    }

    public int getPosition() {
        return this.i_position;
    }

    public final InstructionHandle getPrev() {
        return this.prev;
    }

    public InstructionTargeter[] getTargeters() {
        if (!hasTargeters()) {
            return EMPTY_INSTRUCTION_TARGETER_ARRAY;
        }
        InstructionTargeter[] t = new InstructionTargeter[this.targeters.size()];
        this.targeters.toArray(t);
        return t;
    }

    public boolean hasTargeters() {
        return (this.targeters == null || this.targeters.isEmpty()) ? false : true;
    }

    public void removeAllTargeters() {
        if (this.targeters != null) {
            this.targeters.clear();
        }
    }

    public void removeAttribute(Object key) {
        if (this.attributes != null) {
            this.attributes.remove(key);
        }
    }

    public void removeTargeter(InstructionTargeter t) {
        if (this.targeters != null) {
            this.targeters.remove(t);
        }
    }

    public void setInstruction(Instruction i) {
        if (i == null) {
            throw new ClassGenException("Assigning null to handle");
        }
        if (getClass() != BranchHandle.class && (i instanceof BranchInstruction)) {
            throw new ClassGenException("Assigning branch instruction " + i + " to plain handle");
        }
        if (this.instruction != null) {
            this.instruction.dispose();
        }
        this.instruction = i;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final InstructionHandle setNext(InstructionHandle next) {
        this.next = next;
        return next;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void setPosition(int pos) {
        this.i_position = pos;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final InstructionHandle setPrev(InstructionHandle prev) {
        this.prev = prev;
        return prev;
    }

    public Instruction swapInstruction(Instruction i) {
        Instruction oldInstruction = this.instruction;
        this.instruction = i;
        return oldInstruction;
    }

    public String toString() {
        return toString(true);
    }

    public String toString(boolean verbose) {
        return Utility.format(this.i_position, 4, false, ' ') + ": " + this.instruction.toString(verbose);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public int updatePosition(int offset, int maxOffset) {
        this.i_position += offset;
        return 0;
    }
}
